@@ -9,17 +9,16 @@
 #![allow(clippy::shadow_unrelated)]
 #![allow(clippy::missing_errors_doc)]
 #![allow(clippy::used_underscore_binding)]
+#![allow(clippy::unsafe_derive_deserialize)]
 
 #[cfg(feature = "diesel_types")]
 #[macro_use]
 extern crate diesel;
 
-pub mod stack_string;
-#[cfg(features = "stack-cow")]
+pub mod small_string;
 pub mod stack_cow;
+pub mod stack_string;
 
-pub use crate::stack_string::StackString;
-#[cfg(features = "stack-cow")]
-pub use crate::stack_cow::StackCow;
+pub use crate::{small_string::SmallString, stack_cow::StackCow, stack_string::StackString};
 
 pub use smartstring::MAX_INLINE;
